# Blocks


::: linax.blocks.base.BlockConfig
    options:
        members:
            - build

---

::: linax.blocks.base.Block
    options:
        members:
            - __init__
            - __call__
